<?php
namespace OrganizationsManagement\Controller;
use React\Stream\Util;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource;
use OrganizationsManagement\Service;
use OrganizationsManagement\Util\Messages;
use OrganizationsManagement\Util\Utilities;

class Elemento extends Simple
{
    /** @var Service\Elemento $serviceElemento */
    protected $serviceElemento;

    public function __construct(Service\Elemento $serviceElemento){
        $this->serviceElemento = $serviceElemento;
    }

    public function save(DTO\Request\DataSet $request, DTO\Response $response){
        $requestRow = $request->getDataSet()->getRows()[0];
        $urlJsonFile = $requestRow['urlJsonFile'];
        $productId = $requestRow['productId'];
        try {
            $elements = $this->serviceElemento->save($productId, $urlJsonFile);
            $response->addDataSet(new DataSource\DataSet('elements', $elements));
        } catch(\Exception $ex) {
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function saveElementsInOrganizations(DTO\Request\DataSet $request, DTO\Response $response){
        $requestRow = $request->getDataSet()->getRows()[0];
        $elements = $requestRow['elementsToUpdate'];
        $organizations = $requestRow['organizations'];
        try {
            $result = $this->serviceElemento->saveElementsInOrganizations($elements, $organizations);
            $response->addDataSet(new DataSource\DataSet('data', $result));
        } catch(\Exception $ex) {
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function getMenuChanges(DTO\Request\Filter $request, DTO\Response $response){
        try {
            $conditions = $request->getFilterCriteria()->getConditions();
            $urlJsonFile = Utilities::getValueInFilterDataSourceByName($conditions, 'URL_JSON_FILE', true);
            $productId = Utilities::getValueInFilterDataSourceByName($conditions, 'PRODUCT_ID', true);
            
            $changes = $this->serviceElemento->getMenuChanges($urlJsonFile, $productId);
            $response->addDataSet(new DataSource\DataSet('getMenuChanges', $changes));
        } catch(\Exception $ex) {
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function getElements(DTO\Request\Filter $request, DTO\Response $response){
        try { 
            $filters = $request->getFilterCriteria()->getConditions();
            $productId  = Utilities::getValueInFilterDataSourceByName($filters, 'PROJECT_ID', true);
            $elements   = $this->serviceElemento->getElements($productId, $filters);
            $response->addDataSet(new DataSource\DataSet('elements', $elements));
        } catch(\Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }
}