<?php

namespace OrganizationsManagement\Repository;

use OrganizationsManagement\Util\InstanceProvider;

class Organization
{
    public function saveOrganizationLogDir($log, $orgId) {
        $query = <<<SQL
          UPDATE ORGANIZACAO
             SET DSDIRLOG = :DSDIRLOG
           WHERE NRORG = :NRORG
SQL;
        $param = array(
            "DSDIRLOG" => $log,
            "NRORG" => $orgId
        );
        return InstanceProvider::getEntityManager()->getConnection()->executeQuery($query, $param);
    }

    public function getOrganizationLogDir($orgId) {
        $query = <<<SQL
          SELECT DSDIRLOG
            FROM ORGANIZACAO
           WHERE NRORG = :NRORG
SQL;
        $param = array (
            "NRORG" => $orgId
        );
        return InstanceProvider::getEntityManager()->getConnection()->fetchAssoc($query, $param);
    }

    public function verifyError($nrorg, &$errors, $errorToVerify, $isParameterError) {
        $parameters = InstanceProvider::getRepository()->getOmParamOrg()->getOrganizationParameters($nrorg);
        $dbUserName = empty($parameters) || empty($parameters[0]['DSUSUARIOBANCO']) ? "USR_ORG_$nrorg" : $parameters[0]['DSUSUARIOBANCO'];
        if(!$isParameterError) {
            $query = <<<SQL
              SELECT OWNER, COUNT(*) AS VARIABLE
                FROM DBA_$errorToVerify
               WHERE OWNER IN ('OM', '$dbUserName')
            GROUP BY OWNER
SQL;
            $queryResult = InstanceProvider::getDBConnection()->getOrgEntityManager(null, true)->getConnection()->fetchAll($query);
            if(sizeof($queryResult) < 2) {
                array_unshift($errors, $errorToVerify);
            } else{
                $checkResult = $this->checkQueryResult($queryResult, false);
                if(!$checkResult){
                    array_unshift($errors, $errorToVerify);
                }
            }
        } else {
            $query = <<<SQL
              SELECT COUNT(*) AS VARIABLE
                FROM $dbUserName.PARAMHTTPGERAL
SQL;
            $queryResult = InstanceProvider::getDBConnection()->getOrgEntityManager(null, true)->getConnection()->fetchAll($query);
            if(sizeof($queryResult) == 0) {
                array_push($errors, $errorToVerify);
            } else {
                $checkResult = $this->checkQueryResult($queryResult, true);
                if(!$checkResult){
                    array_push($errors, $errorToVerify);
                }
            }
        }
    }

    public function verifyBaseErrors($nrorg){
        $errors = [];

        $this->verifyError($nrorg, $errors, "CONSTRAINTS", false);
        //$this->verifyError($nrorg, $errors, "PROCEDURES", false);
        //$this->verifyError($nrorg, $errors, "TRIGGERS", false);
        $this->verifyError($nrorg, $errors, "INDEXES", false);
        $this->verifyError($nrorg, $errors, "OBJECTS", false);
        //$this->verifyError($nrorg, $errors, "TABLES", false);
        $this->verifyError($nrorg, $errors, "PARAMETERS", true);


        return implode("<br/>", $errors);
    }

    public function checkQueryResult($queryResult, $parameters){
        if($parameters){
            return $queryResult[0]['VARIABLE'] > 0;
        } else{
            return $queryResult[0]['VARIABLE'] == $queryResult[1]["VARIABLE"];
        }
    }

    public function saveOrganizationPrepStatusBkp($status, $orgId) {
        $query = <<<SQL
          UPDATE ORGANIZACAO
             SET PREPSTATUSBKP = :PREPSTATUSBKP
           WHERE NRORG = :NRORG
SQL;
        $param = array(
            "PREPSTATUSBKP" => $status,
            "NRORG" => $orgId
        );
        return InstanceProvider::getEntityManager()->getConnection()->executeQuery($query, $param);
    }
    public function saveScoreReport($score, $alert, $director, $responsible, $godfather, $manager, $inProject, $nrorg) {
        $query = <<<SQL
          UPDATE ORGANIZACAO
             SET SCORE = :SCORE,
                 ALERT = :ALERT,
                 DIRECTOR = :DIRECTOR,
                 RESPONSIBLE = :RESPONSIBLE,
                 GODFATHER = :GODFATHER,
                 MANAGER = :MANAGER,
                 IN_PROJECT = :IN_PROJECT
           WHERE NRORG = :NRORG
SQL;
        $param = array(
            "SCORE" => $score,
            "ALERT" => $alert,
            "DIRECTOR" => $director,
            "RESPONSIBLE" => $responsible,
            "GODFATHER" => $godfather,
            "MANAGER" => $manager,
            "IN_PROJECT" => $inProject,
            "NRORG" => $nrorg
        );
        return InstanceProvider::getEntityManager()->getConnection()->executeQuery($query, $param);
    }

    public function getOrganizationPrepStatusBkp($orgId) {
        $query = <<<SQL
          SELECT PREPSTATUSBKP
            FROM ORGANIZACAO
           WHERE NRORG = :NRORG
SQL;
        $param = array (
            "NRORG" => $orgId
        );
        return InstanceProvider::getEntityManager()->getConnection()->fetchAssoc($query, $param);
    }

    public function getAccessProfileFromClients($nrorg){
        $query = <<<SQL
          SELECT NRPERFILACESSO
          FROM PERFILACESSO
          WHERE (UPPER(NMPERFILACESSO) LIKE ('CLIENTE') OR UPPER(NMPERFILACESSO) LIKE ('CLIENTES'))
          AND IDATIVO = 'S'
          AND NRORG = :NRORG
SQL;
        $param = array (
            "NRORG" => $nrorg
        );
        return InstanceProvider::getEntityManager()->getConnection()->fetchAll($query, $param);
    }

    public function getOperResp($cdOperador){
        $query = <<<SQL
                SELECT E.CDOPERRESP
                  FROM EQUIPETRAB E, FUNCIONARIO F, OPERADOR O
                 WHERE O.CDOPERADOR = :P_CDOPERADOR
                   AND F.CDFUNC = O.CDFUNC
                   AND F.CDEMPRESA = O.CDEMPRESA
                   AND E.CDEQUIPETRAB = F.CDEQUIPETRAB
SQL;
        $param = array (
            "P_CDOPERADOR" => $cdOperador
        );
        return InstanceProvider::getEntityManager()->getConnection()->fetchAll($query, $param);
    }
} 